@@ -138,6 +138,18 @@ Integer v_scalar_product(const vector<Integer>& av,const vector<Integer>& bv){
 
 //---------------------------------------------------------------------------
 
+template<typename Integer>
+Integer v_scalar_product_unequal_vectors_begin(const vector<Integer>& a,const vector<Integer>& b){
+    Integer ans = 0;
+    size_t i,n=min(a.size(),b.size());
+    for (i = 0; i < n; i++) {
+        ans+=a[i]*b[i];
+    }
+    return ans;
+}
+
+//---------------------------------------------------------------------------
+
 template<typename Integer>
 Integer v_scalar_product_unequal_vectors_end(const vector<Integer>& a,const vector<Integer>& b){
     Integer ans = 0;
@@ -147,7 +159,6 @@ Integer v_scalar_product_unequal_vectors_end(const vector<Integer>& a,const vect
     }
     return ans;
 }
-
 //---------------------------------------------------------------------------
 
 template<typename Integer>
@@ -308,17 +319,6 @@ vector<Integer> v_scalar_mult_mod(const vector<Integer>& v, const Integer& scala
 
 //---------------------------------------------------------------------------
 
-template<typename Integer>
-void v_scalar_division(vector<Integer>& v, const Integer& scalar){
-    size_t i,size=v.size();
-    for (i = 0; i <size; i++) {
-        assert(v[i]%scalar == 0);
-        v[i] /= scalar;
-    }
-}
-
-//---------------------------------------------------------------------------
-
 template<typename Integer>
 void v_reduction_modulo(vector<Integer>& v, const Integer& modulo){
     size_t i,size=v.size();
